ChoiceGroup class abstract

Constructors

ChoiceGroup()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createHeader({bool? dense, TextStyle? textStyle, EdgeInsetsGeometry? contentPadding = defaultHeaderPadding, bool hideCounter = false}) → ChoiceGroupHeaderBuilder
Create default group header builder
createItem() → ChoiceGroupItemBuilder
Create default group item builder
createList({bool shrinkWrap = true, ScrollPhysics? physics, EdgeInsetsGeometry? padding = defaultListPadding}) → ChoiceGroupBuilder
Create default group list builder
createSelectableHeader<T>({bool? dense, TextStyle? textStyle, EdgeInsetsGeometry? contentPadding = defaultHeaderPadding, bool hideCounter = false, required T valueResolver(int i)}) → ChoiceGroupHeaderBuilder<T>
Create selectable group header builder